@@ -245,17 +245,19 @@ function InlinePanel(opts) {
 
     buildExpandingFormset(opts.formsetPrefix, {
         onAdd: function(formCount) {
-            var newChildPrefix = opts.emptyChildFormPrefix.replace(/__prefix__/g, formCount);
-            self.initChildControls(newChildPrefix);
+            function fixPrefix(str) {
+                return str.replace(/__prefix__/g, formCount);
+            }
+            self.initChildControls(fixPrefix(opts.emptyChildFormPrefix));
             if (opts.canOrder) {
                 /* NB form hidden inputs use 0-based index and only increment formCount *after* this function is run.
                 Therefore formcount and order are currently equal and order must be incremented
                 to ensure it's *greater* than previous item */
-                $('#id_' + newChildPrefix + '-ORDER').val(formCount + 1);
+                $(fixPrefix('#id_' + opts.emptyChildFormPrefix + '-ORDER')).val(formCount + 1);
             }
             self.updateMoveButtonDisabledStates();
 
-            if (opts.onAdd) opts.onAdd();
+            opts.onAdd(fixPrefix);
         }
     });
 
