@@ -3,6 +3,7 @@ from django.shortcuts import get_object_or_404, render
 from django.http import Http404
 from django.utils.http import urlencode
 from django.contrib.auth.decorators import permission_required
+from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
 
 from wagtail.wagtailadmin.modal_workflow import render_modal_workflow
 from wagtail.wagtailadmin.forms import SearchForm, ExternalLinkChooserForm, ExternalLinkChooserWithLinkTextForm, EmailLinkChooserForm, EmailLinkChooserWithLinkTextForm
@@ -25,6 +26,7 @@ def browse(request, parent_page_id=None):
     content_type_app_name, content_type_model_name = page_type.split('.')
 
     is_searching = False
+    page_types_restricted = page_type != 'wagtailcore.page'
 
     try:
         content_type = ContentType.objects.get_by_natural_key(content_type_app_name, content_type_model_name)
@@ -66,8 +68,11 @@ def browse(request, parent_page_id=None):
         return render(request, 'wagtailadmin/chooser/_search_results.html', {
             'querystring': get_querystring(request),
             'searchform': search_form,
-            'pages': pages,
-            'is_searching': is_searching
+            'pages': shown_pages,
+            'is_searching': is_searching,
+            'page_type_string': page_type,
+            'page_type': desired_class,
+            'page_types_restricted': page_types_restricted
         })
 
     return render_modal_workflow(request, 'wagtailadmin/chooser/browse.html', 'wagtailadmin/chooser/browse.js', {
@@ -77,7 +82,10 @@ def browse(request, parent_page_id=None):
         'parent_page': parent_page,
         'pages': shown_pages,
         'search_form': search_form,
-        'is_searching': False
+        'is_searching': False,
+        'page_type_string': page_type,
+        'page_type': desired_class,
+        'page_types_restricted': page_types_restricted
     })
 
 
