@@ -1,5 +1,6 @@
 import warnings
 import datetime
+import json
 
 import pytz
 
@@ -7,6 +8,7 @@ from django.test import TestCase, Client
 from django.test.utils import override_settings
 from django.http import HttpRequest, Http404
 from django.contrib.contenttypes.models import ContentType
+from django.contrib.auth import get_user_model
 
 from wagtail.wagtailcore.models import Page, Site
 from wagtail.tests.models import EventPage, EventIndex, SimplePage, PageWithOldStyleRouteMethod, BusinessIndex, BusinessSubIndex, BusinessChild, StandardIndex
@@ -425,11 +427,23 @@ class TestCopyPage(TestCase):
         new_christmas_event = christmas_event.copy(update_attrs={'title': "New christmas event", 'slug': 'new-christmas-event'})
 
         # Check that the revisions were copied
-        self.assertEqual(new_christmas_event.revisions.count(), 1, "Revisions weren't copied")
+        # Copying creates a new revision so we're expecting the new page to have two revisions
+        self.assertEqual(new_christmas_event.revisions.count(), 2)
 
         # Check that the revisions weren't removed from old page
         self.assertEqual(christmas_event.revisions.count(), 1, "Revisions were removed from the original page")
 
+        # Check that the attributes were updated in the latest revision
+        latest_revision = new_christmas_event.get_latest_revision_as_page()
+        self.assertEqual(latest_revision.title, "New christmas event")
+        self.assertEqual(latest_revision.slug, 'new-christmas-event')
+
+        # Check that the ids within the revision were updated correctly
+        new_revision = new_christmas_event.revisions.first()
+        new_revision_content = json.loads(new_revision.content_json)
+        self.assertEqual(new_revision_content['pk'], new_christmas_event.id)
+        self.assertEqual(new_revision_content['speakers'][0]['page'], new_christmas_event.id)
+
     def test_copy_page_copies_revisions_and_doesnt_submit_for_moderation(self):
         christmas_event = EventPage.objects.get(url_path='/home/events/christmas/')
         christmas_event.save_revision(submitted_for_moderation=True)
@@ -438,10 +452,10 @@ class TestCopyPage(TestCase):
         new_christmas_event = christmas_event.copy(update_attrs={'title': "New christmas event", 'slug': 'new-christmas-event'})
 
         # Check that the old revision is still submitted for moderation
-        self.assertTrue(christmas_event.revisions.first().submitted_for_moderation)
+        self.assertTrue(christmas_event.revisions.order_by('created_at').first().submitted_for_moderation)
 
         # Check that the new revision is not submitted for moderation
-        self.assertFalse(new_christmas_event.revisions.first().submitted_for_moderation)
+        self.assertFalse(new_christmas_event.revisions.order_by('created_at').first().submitted_for_moderation)
 
     def test_copy_page_copies_revisions_and_doesnt_change_created_at(self):
         christmas_event = EventPage.objects.get(url_path='/home/events/christmas/')
@@ -456,8 +470,8 @@ class TestCopyPage(TestCase):
         new_christmas_event = christmas_event.copy(update_attrs={'title': "New christmas event", 'slug': 'new-christmas-event'})
 
         # Check that the created_at time is the same
-        christmas_event_created_at = christmas_event.get_latest_revision().created_at
-        new_christmas_event_created_at = new_christmas_event.get_latest_revision().created_at
+        christmas_event_created_at = christmas_event.revisions.order_by('created_at').first().created_at
+        new_christmas_event_created_at = new_christmas_event.revisions.order_by('created_at').first().created_at
         self.assertEqual(christmas_event_created_at, new_christmas_event_created_at)
 
     def test_copy_page_copies_revisions_and_doesnt_schedule(self):
@@ -468,10 +482,10 @@ class TestCopyPage(TestCase):
         new_christmas_event = christmas_event.copy(update_attrs={'title': "New christmas event", 'slug': 'new-christmas-event'})
 
         # Check that the old revision is still scheduled
-        self.assertEqual(christmas_event.revisions.first().approved_go_live_at, datetime.datetime(2014, 9, 16, 9, 12, 00, tzinfo=pytz.utc))
+        self.assertEqual(christmas_event.revisions.order_by('created_at').first().approved_go_live_at, datetime.datetime(2014, 9, 16, 9, 12, 00, tzinfo=pytz.utc))
 
         # Check that the new revision is not scheduled
-        self.assertEqual(new_christmas_event.revisions.first().approved_go_live_at, None)
+        self.assertEqual(new_christmas_event.revisions.order_by('created_at').first().approved_go_live_at, None)
 
     def test_copy_page_doesnt_copy_revisions_if_told_not_to_do_so(self):
         christmas_event = EventPage.objects.get(url_path='/home/events/christmas/')
@@ -481,7 +495,8 @@ class TestCopyPage(TestCase):
         new_christmas_event = christmas_event.copy(update_attrs={'title': "New christmas event", 'slug': 'new-christmas-event'}, copy_revisions=False)
 
         # Check that the revisions weren't copied
-        self.assertEqual(new_christmas_event.revisions.count(), 0, "Revisions were copied")
+        # Copying creates a new revision so we're expecting the new page to have one revision
+        self.assertEqual(new_christmas_event.revisions.count(), 1)
 
         # Check that the revisions weren't removed from old page
         self.assertEqual(christmas_event.revisions.count(), 1, "Revisions were removed from the original page")
@@ -544,7 +559,8 @@ class TestCopyPage(TestCase):
         new_christmas_event = new_events_index.get_children().filter(slug='christmas').first()
 
         # Check that the revisions were copied
-        self.assertEqual(new_christmas_event.specific.revisions.count(), 1, "Revisions weren't copied")
+        # Copying creates a new revision so we're expecting the new page to have two revisions
+        self.assertEqual(new_christmas_event.specific.revisions.count(), 2)
 
         # Check that the revisions weren't removed from old page
         self.assertEqual(old_christmas_event.specific.revisions.count(), 1, "Revisions were removed from the original page")
@@ -561,11 +577,29 @@ class TestCopyPage(TestCase):
         new_christmas_event = new_events_index.get_children().filter(slug='christmas').first()
 
         # Check that the revisions weren't copied
-        self.assertEqual(new_christmas_event.specific.revisions.count(), 0, "Revisions were copied")
+        # Copying creates a new revision so we're expecting the new page to have one revision
+        self.assertEqual(new_christmas_event.specific.revisions.count(), 1)
 
         # Check that the revisions weren't removed from old page
         self.assertEqual(old_christmas_event.specific.revisions.count(), 1, "Revisions were removed from the original page")
 
+    def test_copy_page_updates_user(self):
+        event_moderator = get_user_model().objects.get(username='eventmoderator')
+        christmas_event = EventPage.objects.get(url_path='/home/events/christmas/')
+        christmas_event.save_revision()
+
+        # Copy it
+        new_christmas_event = christmas_event.copy(
+            update_attrs={'title': "New christmas event", 'slug': 'new-christmas-event'},
+            user=event_moderator,
+        )
+
+        # Check that the owner has been updated
+        self.assertEqual(new_christmas_event.owner, event_moderator)
+
+        # Check that the user on the last revision is correct
+        self.assertEqual(new_christmas_event.get_latest_revision().user, event_moderator)
+
 
 class TestSubpageTypeBusinessRules(TestCase):
     def test_allowed_subpage_types(self):
